┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphinnewmenu.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dolphinnewmenu.h')
-rw-r--r--src/dolphinnewmenu.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/dolphinnewmenu.h b/src/dolphinnewmenu.h
index b1a95edc9..176c84648 100644
--- a/src/dolphinnewmenu.h
+++ b/src/dolphinnewmenu.h
@@ -30,11 +30,11 @@ class KJob;
* @brief Represents the 'Create New...' sub menu for the File menu
* and the context menu.
*
* The only difference to KNewMenu is the custom error handling.
* All errors are shown in the status bar of Dolphin
* instead as modal error dialog with an OK button.
*/
-class DolphinNewMenu : public KNewMenu
+class DolphinNewMenu : public KNewFileMenu
{
Q_OBJECT
@@ -43,7 +43,7 @@ public:
virtual ~DolphinNewMenu();
protected slots:
- /** @see KNewMenu::slotResult() */
+ /** @see KNewFileMenu::slotResult() */
virtual void slotResult(KJob* job);
private:
@@ -30,11 +30,11 @@ class KJob;
* and the context menu.
*
- * The only difference to KNewMenu is the custom error handling.
+ * The only difference to KNewFileMenu is the custom error handling.
* All errors are shown in the status bar of Dolphin
* instead as modal error dialog with an OK button.